@@ -68,6 +68,7 @@ class AbstractModule:
     # pylint: disable=too-many-arguments
     def bind(self,
              target_type: Type[InjectedT],
+             *,
              to_class: Type[InjectedT] = EMPTY,
              to_instance: InjectedT = EMPTY,
              to_provider: Union[Provider, Type[Provider]] = EMPTY,
@@ -97,34 +98,36 @@ class AbstractModule:
     def multi_bind(self,
                    item_target_type: Type[InjectedT],
                    item_bindings: List[ItemBinding[InjectedT]],
+                   *,
                    scope: Type[Scope] = SingletonScope,
                    named: Optional[str] = None,
                    override_bindings: bool = True) -> RegisteredBinding:
 
         return self._register_multi_binding(
-            MultiBinding(item_target_type, item_bindings, scope, named, override_bindings)
+            MultiBinding(item_target_type, item_bindings, scope=scope, named=named, override_bindings=override_bindings)
         )
 
     @staticmethod
-    def bind_item(to_class: Type[InjectedT] = EMPTY,
+    def bind_item(*,
+                  to_class: Type[InjectedT] = EMPTY,
                   to_instance: InjectedT = EMPTY,
                   to_provider: Union[Provider, Type[Provider]] = EMPTY) -> ItemBinding[InjectedT]:
-        return ItemBinding(to_class, to_instance, to_provider)
+        return ItemBinding(bound_class=to_class, bound_instance=to_instance, bound_provider=to_provider)
 
     @staticmethod
     def _create_binding(target_type: Type[InjectedT],
-                        bound_type: Type[InjectedT],
+                        bound_class: Type[InjectedT],
                         bound_instance: InjectedT,
                         bound_provider: Union[Provider, Type[Provider]],
                         scope: Type[Scope],
                         named: Optional[str]) -> Binding:
         if bound_instance is not EMPTY:
-            return InstanceBinding(target_type, bound_instance, named)
+            return InstanceBinding(target_type, bound_instance, named=named)
         if bound_provider is not EMPTY:
-            return ProviderBinding(target_type, bound_provider, scope, named)
-        if bound_type is not EMPTY and bound_type != target_type:
-            return ClassBinding(target_type, bound_type, scope, named)
-        return SelfBinding(target_type, scope, named)
+            return ProviderBinding(target_type, bound_provider, scope=scope, named=named)
+        if bound_class is not EMPTY and bound_class != target_type:
+            return ClassBinding(target_type, bound_class, scope=scope, named=named)
+        return SelfBinding(target_type, scope=scope, named=named)
 
     def _register(self, binding: Binding[InjectedT]) -> RegisteredBinding:
         if isinstance(binding, MultiBinding):
@@ -137,24 +140,24 @@ class AbstractModule:
     def _register_multi_binding(self, binding: MultiBinding[InjectedT]) -> RegisteredMultiBinding:
         registered_binding = RegisteredMultiBinding(binding)
         for item_binding in binding.item_bindings:
-            if item_binding.bound_type is not EMPTY:
+            if item_binding.bound_class is not EMPTY:
                 item_binding = SelfBinding(
-                    item_binding.bound_type,
-                    binding.scope,
-                    binding.named,
+                    item_binding.bound_class,
+                    scope=binding.scope,
+                    named=binding.named,
                 )
             elif item_binding.bound_instance is not EMPTY:
                 item_binding = InstanceBinding(
                     binding.item_target_type,
                     item_binding.bound_instance,
-                    binding.named,
+                    named=binding.named,
                 )
             elif item_binding.bound_provider is not EMPTY:
                 item_binding = ProviderBinding(
                     binding.item_target_type,
                     item_binding.bound_provider,
-                    binding.scope,
-                    binding.named,
+                    scope=binding.scope,
+                    named=binding.named,
                 )
             else:
                 raise BindingError(
