@@ -17,6 +17,6 @@ class ClassBindingToProviderAdapter(BindingToProviderAdapter[ClassBinding]):
     def create(self,
                binding: RegisteredBinding[ClassBinding[InjectedT]],
                context: InjectionContext[InjectedT]) -> Provider:
-        new_target = Target(binding.raw_binding.bound_type, binding.raw_binding.named)
+        new_target = Target(binding.raw_binding.bound_class, binding.raw_binding.named)
         new_context = context.get_child_context(new_target)
         return new_context.get_provider()
